package tests

// Some funcs
import (
	"fmt"
	"reflect"
	"testing"

	vecasm "github.com/gohxs/vec-benchmark/asm"
)

func VecMul(a, b []float32) []float32 {

	sz := Min(len(a), len(b))

	out := make([]float32, sz)
	vecasm.VecMulf32x8(a, b, out)
	return out
}
func VecAdd(a, b []float32) []float32 {
	sz := Min(len(a), len(b))
	out := make([]float32, sz)
	for i := 0; i < sz; i++ {
		out[i] = a[i] + b[i]
	}
	return out
}
func VecDiv(a, b []float32) []float32 {
	sz := Min(len(a), len(b))
	out := make([]float32, sz)
	for i := 0; i < sz; i++ {
		out[i] = a[i] / b[i]
	}
	return out
}

// ScalarInt
// Every time this operator is called we increase 1
func Inc() func() int {
	i := 0
	return func() int {
		i++
		return i
	}
}
func Add(a, b int) int {
	return a + b
}

// Utils
func Min(p ...int) int {
	min := p[0]
	for _, v := range p[1:] {
		if min < v {
			min = v
		}
	}
	return min
}
func CheckErr(t *testing.T, err error) {
	if err != nil {
		t.Fatal(err)
	}
}

func CheckEq(t *testing.T, a, b interface{}) {
	msg := fmt.Sprintf("Expect %v got %v", a, b)
	if !reflect.DeepEqual(a, b) {
		t.Fatalf("\033[31m[FAIL] %s\033[0m", msg)
	}
	t.Logf("\033[32m[PASS]\033[m %s", msg)
}

func CheckDiff(t *testing.T, a, b interface{}) {
	msg := fmt.Sprintf("Expect NOT %v got %v", a, b)
	if reflect.DeepEqual(a, b) {
		t.Fatalf("\033[31m[FAIL] %s\033[0m", msg)
	}
	t.Logf("\033[32m[PASS]\033[m %s", msg)
}
